@@ -30,11 +30,8 @@ pub mod nvv;
 pub mod oebb;
 #[cfg(feature = "ooevv-profile")]
 pub mod ooevv;
-#[cfg(feature = "vgi-profile")]
-pub mod vgi;
-// Currently disabled due to: Does not answer requests for location query.
-// #[cfg(feature = "pkp-profile")]
-// pub mod pkp;
+#[cfg(feature = "pkp-profile")]
+pub mod pkp;
 #[cfg(feature = "rejseplanen-profile")]
 pub mod rejseplanen;
 #[cfg(feature = "rmv-profile")]
@@ -47,6 +44,8 @@ pub mod saarvv;
 pub mod salzburg;
 #[cfg(feature = "sbahn-muenchen-profile")]
 pub mod sbahn_muenchen;
+#[cfg(feature = "vgi-profile")]
+pub mod vgi;
 // Currently broken due to: <https://github.com/public-transport/hafas-client/issues/284>
 // #[cfg(feature = "sncf-profile")]
 // pub mod sncf;
@@ -141,8 +140,8 @@ pub fn profile_from_name<S: AsRef<str>>(name: S) -> Option<Box<dyn Profile>> {
         "nahsh" => Some(Box::new(nahsh::NahSHProfile {})),
         #[cfg(feature = "vvt-profile")]
         "vvt" => Some(Box::new(vvt::VvtProfile {})),
-        // #[cfg(feature = "pkp-profile")]
-        // "pkp" => Some(Box::new(pkp::PkpProfile {})),
+        #[cfg(feature = "pkp-profile")]
+        "pkp" => Some(Box::new(pkp::PkpProfile {})),
         #[cfg(feature = "irish-rail-profile")]
         "irish-rail" => Some(Box::new(irish_rail::IrishRailProfile {})),
         #[cfg(feature = "mobiliteit-lu-profile")]
